@@ -16,19 +16,19 @@ if(is.logical(s)) {
 obj<-wblr.fit(wblr(x,s), dist="lognormal3p", modify.by.t0=T, col="red2")
 fit<-obj$fit[[1]]$fit_vec
 attributes(fit)$data_types<-NULL
-## bounds are not prepared for 3p fits, so the bounds argument is simply ignored.
-#if(bounds==TRUE) {
-#obj<-wblr.conf(obj, dq="minitab", col="pink2")
-#bnds<-obj$fit[[1]]$conf[[1]]$bounds
-#ret<-list(fit,bnds)
-#stitle<-"MRR fit with 90% double-sided pivotal bounds"
-#}else{
+
+if(bounds==TRUE) {
+obj<-wblr.conf(obj, dq="minitab", col="pink2")
+bnds<-obj$fit[[1]]$conf[[1]]$bounds
+ret<-list(fit,bnds)
+stitle<-"MRR fit with 90% double-sided pivotal bounds"
+}else{
 ret<-fit
 stitle<-"Lognormal MRR 3-parameter fit"
-#}
+}
 
 if(show==TRUE) {
-plot(obj, canvas="lognormal", in.legend.blives=FALSE, sub=stitle)
+plot(obj, canvas="lognormal", in.legend.blives=FALSE, sub=stitle, xlab=("Time - t0"))
 }
 
 ret
