@@ -5,7 +5,8 @@ mlefit<-function(x, dist="weibull", npar=2, debias="none", optcontrol=NULL)  {
 		default_sign=1
 
 ## check basic parameters of x
-	if(class(x)!="data.frame") {stop("mlefit takes a structured dataframe input, use mleframe")}
+	#if(class(x)!="data.frame") stop("FMbounds takes a structured dataframe input, use mleframe")	
+	if(!is(x, "data.frame")) stop("mlefit takes a structured dataframe input, use mleframe")
 	if(ncol(x)!=3)  {stop("mlefit takes a structured dataframe input, use mleframe")}
 	#if(x$right[1] != min(x$right[x$right != -1])) {stop("use mleframe to sort data")
 	xnames<-names(x)
