@@ -12,17 +12,14 @@
 #include <RcppArmadillo.h>
 
 // abremDebias code
-RcppExport SEXP MLEloglike(SEXP arg1, SEXP arg3, SEXP arg4, SEXP arg5, SEXP arg6);
+RcppExport SEXP MLEloglike(SEXP arg1, SEXP arg3, SEXP arg5, SEXP arg6);
 RcppExport SEXP MLEsimplex(SEXP arg1, SEXP arg2, SEXP arg3, SEXP arg4, SEXP arg5);
 // used in secant method for determination of 3rd parameter optimization
-RcppExport SEXP MLEdMaxLLdx(SEXP arg1, SEXP arg2, SEXP arg3, SEXP arg4);
+//RcppExport SEXP MLEdMaxLLdx(SEXP arg1, SEXP arg2, SEXP arg3, SEXP arg4);
 //******************//
-// end abremDebias
 
-
-// abremPivotals code
-RcppExport SEXP LSLR(SEXP arg1, SEXP arg2, SEXP arg3, SEXP arg4);
-RcppExport SEXP pivotalMC(SEXP arg1, SEXP arg2, SEXP arg3, SEXP arg4, SEXP arg5, SEXP arg6,SEXP arg7,SEXP arg8);
+RcppExport SEXP LSLR(SEXP arg1);
+RcppExport SEXP pivotalMC(SEXP arg1);
 //RcppExport SEXP CallgetCCC2(SEXP arg1, SEXP model);
 //RcppExport SEXP CallgetPvalue(SEXP arg1, SEXP arg2, SEXP arg3);
 
@@ -35,7 +32,10 @@ RcppExport SEXP adjustedRank (SEXP arg1);
 // dpoints and dlines loop
 RcppExport SEXP plotData(SEXP arg1, SEXP arg2, SEXP arg3, SEXP arg4, SEXP arg5, SEXP arg6, SEXP arg7);
 // contour code
-RcppExport SEXP getContour(SEXP arg1, SEXP arg2, SEXP arg3, SEXP arg4, SEXP arg5, SEXP arg6, SEXP arg7);
+RcppExport SEXP getContour(SEXP arg1, SEXP arg2, SEXP arg4, SEXP arg5, SEXP arg6, SEXP arg7);
+// MLE 3p code
+RcppExport SEXP callMLE3p(SEXP arg1, SEXP arg2, SEXP arg3, SEXP arg4, SEXP arg5);
+	     //SEXP callMLE3p(SEXP arg1, SEXP arg2, SEXP arg3, SEXP arg4, SEXP arg5) {		//implementation
 
 extern "C" void R_init_WeibullR(DllInfo* info);
 
